==> message-service-api-0.1.12-sources.jar: cn/com/duiba/message/service/api/remoteservice/RemoteCallService.java <==
package cn.com.duiba.message.service.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.message.service.api.dto.CallReport;
import cn.com.duiba.message.service.api.dto.CallResult;

import java.util.concurrent.TimeUnit;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2019年01月29日 16:50
 * @descript:
 * @version: 1.0
 */
@AdvancedFeignClient
public interface RemoteCallService {

    /**
     * 打电话
     *
     * @param mobile   手机号
     * @param ttsParam 模版里的参数变量json（当模板中存在变量时需要设置此值）
     * @param ttsCode  电话模版（需要根据既定的模板生成的内容，业务方需要在阿里云语音服务控制台添加好对应的模板）
     * @return
     * @throws BizException
     */
    CallResult call(String ttsCode, String mobile, String ttsParam) throws BizException;

    /**
     * 查询呼叫记录
     *
     * @param callId 呼叫ID
     * @return
     * @throws BizException
     */
    CallReport queryCallReport(Long callId) throws BizException;


    /**
     * 通过系统名称给系统owner拨打电话：
     * - 随机给owner拨号，有一个接通之后不再拨号，如都没有接听，继续给业务线服务人拨号（随机），有一个拨号成功立马返回
     * @param appName 系统名称
     * @param ttsCode 电话模版（需要根据既定的模板生成的内容，业务方需要在阿里云语音服务控制台添加好对应的模板）
     * @param ttsParam 模版里的参数变量json（当模板中存在变量时需要设置此值）
     * @param maxWaitTime 等待拨号成功的时间，0表示一直等待
     * @param waitTimeUnit 等待拨号成功的时间单位
     * @return
     * @throws BizException 如果遇到阿里云接口限流抛出异常
     */
    CallReport callByAppName(String appName, String ttsCode, String ttsParam, long maxWaitTime, TimeUnit waitTimeUnit) throws BizException;



}

==> message-service-api-0.1.15-sources.jar: cn/com/duiba/message/service/api/remoteservice/RemoteCallService.java <==
package cn.com.duiba.message.service.api.remoteservice;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.message.service.api.dto.CallReport;
import cn.com.duiba.message.service.api.dto.CallResult;

import java.util.concurrent.TimeUnit;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2019年01月29日 16:50
 * @descript:
 * @version: 1.0
 */
@AdvancedFeignClient
public interface RemoteCallService {

    /**
     * 打电话
     *
     * @param mobile   手机号
     * @param ttsParam 模版里的参数变量json（当模板中存在变量时需要设置此值）
     * @param ttsCode  电话模版（需要根据既定的模板生成的内容，业务方需要在阿里云语音服务控制台添加好对应的模板）
     * @return
     * @throws BizException
     */
    CallResult call(String ttsCode, String mobile, String ttsParam) throws BizException;

    /**
     * 查询呼叫记录
     *
     * @param callId 呼叫ID
     * @return
     * @throws BizException
     */
    CallReport queryCallReport(Long callId) throws BizException;


    /**
     * 通过系统名称给系统owner拨打电话：
     * - 随机给owner拨号，有一个接通之后不再拨号，如都没有接听，继续给业务线服务人拨号（随机），有一个拨号成功立马返回
     * @param appName 系统名称
     * @param ttsCode 电话模版（需要根据既定的模板生成的内容，业务方需要在阿里云语音服务控制台添加好对应的模板）
     * @param ttsParam 模版里的参数变量json（当模板中存在变量时需要设置此值）
     * @param maxWaitTime 等待拨号成功的时间，默认时间是1分钟
     * @param waitTimeUnit 等待拨号成功的时间单位
     * @return
     * @throws BizException 如果遇到阿里云接口限流抛出异常
     */
    boolean callByAppName(String appName, String ttsCode, String ttsParam, long maxWaitTime, TimeUnit waitTimeUnit) throws BizException;
}
